pub struct ArticleAndParentComment {
pub article: Option<TextEntry>,
pub parent_comment: Option<TextEntry>,
}Expand description
A type of context specific to a comment left on a single-threaded comment message board, where comments are either a top level comment or the child of a top level comment.
This type is not used in any activity, and only used as part of another schema.
Fields
article: Option<TextEntry>The source content about which the comment was made (article text, article summary, video transcript, etc).
parent_comment: Option<TextEntry>Refers to text that is a direct parent of the source comment, such as in a one-deep threaded message board. This field will only be present for comments that are replies to other comments and will not be populated for direct comments on the article_text.