pub struct AttributeParameters {
pub score_threshold: Option<f32>,
pub score_type: Option<String>,
}Expand description
Configurable parameters for attribute scoring.
This type is not used in any activity, and only used as part of another schema.
Fields
score_threshold: Option<f32>Don’t return scores for this attribute that are below this threshold. If unset, a default threshold will be applied. A FloatValue wrapper is used to distinguish between 0 vs. default/unset.
score_type: Option<String>What type of scores to return. If unset, defaults to probability scores.