pub struct AttributeScores {
pub span_scores: Option<Vec<SpanScore>>,
pub summary_score: Option<Score>,
}Expand description
This holds score values for a single attribute. It contains both per-span scores as well as an overall summary score..
This type is not used in any activity, and only used as part of another schema.
Fields
span_scores: Option<Vec<SpanScore>>Per-span scores.
summary_score: Option<Score>Overall score for comment as a whole.