pub struct CommentMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on comment resources.
It is not used directly, but through the CommentAnalyzer hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_commentanalyzer1_alpha1 as commentanalyzer1_alpha1;
use commentanalyzer1_alpha1::{CommentAnalyzer, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = CommentAnalyzer::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `analyze(...)` and `suggestscore(...)`
// to build up your call.
let rb = hub.comments();Implementations
Sourceimpl<'a, C> CommentMethods<'a, C>
impl<'a, C> CommentMethods<'a, C>
Sourcepub fn analyze(
&self,
request: AnalyzeCommentRequest,
) -> CommentAnalyzeCall<'a, C>
pub fn analyze( &self, request: AnalyzeCommentRequest, ) -> CommentAnalyzeCall<'a, C>
Create a builder to help you perform the following task:
Analyzes the provided text and returns scores for requested attributes.
Arguments
request- No description provided.
Sourcepub fn suggestscore(
&self,
request: SuggestCommentScoreRequest,
) -> CommentSuggestscoreCall<'a, C>
pub fn suggestscore( &self, request: SuggestCommentScoreRequest, ) -> CommentSuggestscoreCall<'a, C>
Create a builder to help you perform the following task:
Suggest comment scores as training data.
Arguments
request- No description provided.