Context

Struct Context 

pub struct Context {
    pub article_and_parent_comment: Option<ArticleAndParentComment>,
    pub entries: Option<Vec<TextEntry>>,
}
Context is typically something that a Comment is referencing or replying to (such as an article, or previous comment). Note: Populate only ONE OF the following fields. The oneof syntax cannot be used because that would require nesting entries inside another message and breaking backwards compatibility. The server will return an error if more than one of the following fields is present.

This type is not used in any activity, and only used as part of another schema.

Fields

article_and_parent_comment: Option<ArticleAndParentComment>

Information about the source for which the original comment was made, and any parent comment info.

entries: Option<Vec<TextEntry>>

A list of messages. For example, a linear comments section or forum thread.