pub struct Score {
pub type_: Option<String>,
pub value: Option<f32>,
}Expand description
Analysis scores are described by a value and a ScoreType.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>The type of the above value.
value: Option<f32>Score value. Semantics described by type below.