pub struct SpanScore {
pub begin: Option<i32>,
pub end: Option<i32>,
pub score: Option<Score>,
}Expand description
This is a single score for a given span of text.
This type is not used in any activity, and only used as part of another schema.
Fields
begin: Option<i32>“begin” and “end” describe the span of the original text that the attribute score applies to. The values are the UTF-16 codepoint range. “end” is exclusive. For example, with the text “Hi there”, the begin/end pair (0,2) describes the text “Hi”.
If “begin” and “end” are unset, the score applies to the full text.
end: Option<i32>no description provided
score: Option<Score>The score value.