SuggestCommentScoreRequest

Struct SuggestCommentScoreRequest 

pub struct SuggestCommentScoreRequest {
    pub attribute_scores: Option<HashMap<String, AttributeScores>>,
    pub client_token: Option<String>,
    pub comment: Option<TextEntry>,
    pub community_id: Option<String>,
    pub context: Option<Context>,
    pub languages: Option<Vec<String>>,
    pub session_id: Option<String>,
}
The comment score suggestion request message.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

attribute_scores: Option<HashMap<String, AttributeScores>>

Attribute scores for the comment. The map keys are attribute names, same as the requested_attribute field in AnalyzeCommentRequest (for example “ATTACK_ON_AUTHOR”, “INFLAMMATORY”, etc.). This field has the same type as the attribute_scores field in AnalyzeCommentResponse.

To specify an overall attribute score for the entire comment as a whole, use the summary_score field of the mapped AttributeScores object. To specify scores on specific subparts of the comment, use the span_scores field. All SpanScore objects must have begin and end fields set.

All Score objects must be explicitly set (for binary classification, use the score values 0 and 1). If Score objects don’t include a ScoreType, PROBABILITY is assumed.

attribute_scores must not be empty. The mapped AttributeScores objects also must not be empty. An INVALID_ARGUMENT error is returned for all malformed requests.

client_token: Option<String>

Opaque token that is echoed from the request to the response.

comment: Option<TextEntry>

The comment being scored.

community_id: Option<String>

Optional identifier associating this comment score suggestion with a particular sub-community. Different communities may have different norms and rules. Specifying this value enables training community-specific models.

context: Option<Context>

The context of the comment.

languages: Option<Vec<String>>

The language(s) of the comment and context. If none are specified, we attempt to automatically detect the language. Both ISO and BCP-47 language codes are accepted.

session_id: Option<String>

Session ID. Used to join related RPCs into a single session. For example, an interactive tool that calls both the AnalyzeComment and SuggestCommentScore RPCs should set all invocations of both RPCs to the same Session ID, typically a random 64-bit integer.