pub struct SuggestCommentScoreResponse {
pub client_token: Option<String>,
pub detected_languages: Option<Vec<String>>,
pub requested_languages: Option<Vec<String>>,
}Expand description
The comment score suggestion response message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- suggestscore comments (response)
Fields
client_token: Option<String>Same token from the original SuggestCommentScoreRequest.
detected_languages: Option<Vec<String>>The list of languages detected from the comment text.
requested_languages: Option<Vec<String>>The list of languages provided in the request.