pub struct AnalyzeCommentResponse {
pub attribute_scores: Option<HashMap<String, AttributeScores>>,
pub client_token: Option<String>,
pub detected_languages: Option<Vec<String>>,
pub languages: Option<Vec<String>>,
}Expand description
The comment analysis response message.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- analyze comments (response)
Fields
attribute_scores: Option<HashMap<String, AttributeScores>>Scores for the requested attributes. The map keys are attribute names (same as the requested_attribute field in AnalyzeCommentRequest, for example “ATTACK_ON_AUTHOR”, “INFLAMMATORY”, etc).
client_token: Option<String>Same token from the original AnalyzeCommentRequest.
detected_languages: Option<Vec<String>>Contains the languages detected from the text content, sorted in order of likelihood.
languages: Option<Vec<String>>The language(s) used by CommentAnalyzer service to choose which Model to use when analyzing the comment. Might better be called “effective_languages”. The logic used to make the choice is as follows: if !Request.languages.empty() effective_languages = Request.languages else effective_languages = detected_languages[0]